@@ -7,6 +7,7 @@
 #' @importFrom data.table setkeyv
 #' @importFrom data.table shift
 #' @importFrom data.table setDT
+#' @importFrom data.table setnames
 #' @importFrom data.table setcolorder
 #' @importFrom data.table is.data.table
 #' @importFrom data.table :=
@@ -16,6 +17,8 @@
 long2start_stop <- function(data, id, time, varying, overlap=FALSE,
                             check_inputs=TRUE) {
 
+  ..id.. <- ..time.. <- NULL
+
   if (!is.data.frame(data)) {
     stop("'data' should be a data.table or an object that can be transformed",
          " to a data.table (data.frame, tibble, ...).")
@@ -25,7 +28,9 @@ long2start_stop <- function(data, id, time, varying, overlap=FALSE,
 
   # transform to data.table if needed
   if (!is.data.table(data)) {
-    setDT(data)
+    data <- as.data.table(data)
+  } else {
+    data <- copy(data)
   }
 
   if (check_inputs) {
@@ -33,58 +38,61 @@ long2start_stop <- function(data, id, time, varying, overlap=FALSE,
                                  varying=varying)
   }
 
-  start <- .is_equal_to_next <- NULL
-  max_t <- max(data[[time]])
+  setnames(data, old=c(id, time), new=c("..id..", "..time.."))
 
-  setkeyv(data, c(id, time))
+  start <- .is_equal_to_next <- NULL
+  max_t <- max(data$..time..)
+
+  setkeyv(data, c("..id..", "..time.."))
 
   # edge case with no time-varying variables
   if (length(varying)==0) {
 
-    data <- data[eval(parse(text=time))==1,]
-    data[, (time) := NULL]
+    data <- data[..time..==1,]
+    data[, ..time.. := NULL]
     data[, start := 1]
     data[, stop := max_t]
 
-    first_cols <- c(id, "start", "stop")
+    first_cols <- c("..id..", "start", "stop")
     setcolorder(data, c(first_cols,
                         colnames(data)[!colnames(data) %in% first_cols]))
     setkey(data, NULL)
+    setnames(data, old="..id..", new=id)
 
     return(data)
   }
 
   # identify rows that changed
-  data[, .is_equal_to_next := check_next_row_equal(.SD), by=eval(id),
+  data[, .is_equal_to_next := check_next_row_equal(.SD), by="..id..",
        .SDcols=varying]
   data[, .is_equal_to_next := shift(.is_equal_to_next, type="lag"),
-       by=eval((id))]
+       by=..id..]
 
   # remove un-needed rows
-  data <- data[eval(parse(text=time))==1 | eval(parse(text=time))==max_t |
-                 !.is_equal_to_next]
+  data <- data[..time..==1 | ..time..==max_t | !.is_equal_to_next]
   data[, .is_equal_to_next := NULL]
 
   # assign start and stop
-  colnames(data)[colnames(data)==time] <- "start"
-  data[, stop := shift(start, type="lead", fill=max_t), by=eval((id))]
+  setnames(data, old="..time..", new="start")
+  data[, stop := shift(start, type="lead", fill=max_t), by="..id.."]
 
   # remove more rows
-  data <- unique(data, by=c(id, "stop", varying))
+  data <- unique(data, by=c("..id..", "stop", varying))
 
   # correct stop
   data[, stop := fifelse((stop < max_t) | (stop==max_t & seq_len(.N)!=.N),
-                         stop - 1, stop, na=stop), by=eval(id)]
+                         stop - 1, stop, na=stop), by="..id.."]
 
   if (overlap) {
     data[, stop := stop + 1]
   }
 
   # reorder columns
-  first_cols <- c(id, "start", "stop", varying)
+  first_cols <- c("..id..", "start", "stop", varying)
   setcolorder(data, c(first_cols,
                       colnames(data)[!colnames(data) %in% first_cols]))
   setkey(data, NULL)
+  setnames(data, old="..id..", new=id)
 
   return(data)
 }
