@@ -7,7 +7,8 @@ test_that("corrects parents of time_to_event node", {
 
   node_tte <- list(parents=c("A", "B"), name="Ay", prob_fun=f,
                    event_duration=10, immunity_duration=100,
-                   save_past_events=TRUE, type="time_to_event")
+                   save_past_events=TRUE, type_str="time_to_event",
+                   type_fun=node_time_to_event)
 
   new_node <- clean_node_args(node_tte)
 
@@ -22,7 +23,8 @@ test_that("corrects parents of competing_events node", {
 
   node_ce <- list(parents=c("A", "B"), name="By", prob_fun=f,
                   event_duration=c(100, 10), immunity_duration=100,
-                  save_past_events=TRUE, type="competing_events")
+                  save_past_events=TRUE, type_str="competing_events",
+                  type_fun=node_competing_events)
 
   new_node <- clean_node_args(node_ce)
 
@@ -31,7 +33,8 @@ test_that("corrects parents of competing_events node", {
 
 test_that("removes 'name' if not needed", {
 
-  node_tx <- list(parents=c("A", "B"), name="By", type="gaussian")
+  node_tx <- list(parents=c("A", "B"), name="By", type_str="gaussian",
+                  type_fun=node_gaussian)
 
   new_node <- clean_node_args(node_tx)
 
